==> haskell-generics-sop-0.2.5.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generics-sop
version: 0.2.5.0
id: generics-sop-0.2.5.0-4uFPMMqbRNMCAcLGs4abxX
key: generics-sop-0.2.5.0-4uFPMMqbRNMCAcLGs4abxX
license: BSD3
maintainer: andres@well-typed.com
synopsis: Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.
    .
    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.
    .
    Examples of using this library are provided by the following
    packages:
    .
    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,
    .
    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,
    .
    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,
    .
    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.
    .
    A detailed description of the ideas behind this library is provided by
    the paper:
    .
    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.
    .
category: Generics
author: Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>
exposed: True
exposed-modules:
    Generics.SOP Generics.SOP.GGP Generics.SOP.TH Generics.SOP.Dict
    Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Instances
    Generics.SOP.Metadata Generics.SOP.NP Generics.SOP.NS
    Generics.SOP.Universe Generics.SOP.Sing
abi: 58b1861d0b05b20eca9f3f477c764771
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/generics-sop-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/generics-sop-0.2.5.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/generics-sop-0.2.5.0
hs-libraries: HSgenerics-sop-0.2.5.0-4uFPMMqbRNMCAcLGs4abxX
depends:
    base-4.9.1.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock
haddock-html: /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generics-sop-0.3.1.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generics-sop
version: 0.3.1.0
id: generics-sop-0.3.1.0-EVU7jhdnxwRF3s3P6mpp3P
key: generics-sop-0.3.1.0-EVU7jhdnxwRF3s3P6mpp3P
license: BSD3
maintainer: andres@well-typed.com
synopsis: Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.
    .
    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.
    .
    Examples of using this library are provided by the following
    packages:
    .
    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,
    .
    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,
    .
    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,
    .
    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.
    .
    A detailed description of the ideas behind this library is provided by
    the paper:
    .
    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.
    .
category: Generics
author: Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>
exposed: True
exposed-modules:
    Generics.SOP Generics.SOP.GGP Generics.SOP.TH Generics.SOP.Dict
    Generics.SOP.Type.Metadata Generics.SOP.BasicFunctors
    Generics.SOP.Classes Generics.SOP.Constraint Generics.SOP.Instances
    Generics.SOP.Metadata Generics.SOP.NP Generics.SOP.NS
    Generics.SOP.Universe Generics.SOP.Sing
abi: ff4bde208bf0ee1d44f38ede808d6352
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/generics-sop-0.3.1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/generics-sop-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/generics-sop-0.3.1.0
hs-libraries: HSgenerics-sop-0.3.1.0-EVU7jhdnxwRF3s3P6mpp3P
depends:
    base-4.9.1.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock
haddock-html: /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
